@@ -51,16 +51,22 @@ class UserIdentifierType(StringEnum):
 
 
 class RelationType(StringEnum):
-    isCopiedFrom = 'The content of this resource was copied from'
     isPartOf = 'The content of this resource is part of'
-    hasPart = 'Has Part'
-    isExecutedBy = 'The content of this resource can be executed by'
+    hasPart = 'This resource includes'
+    isExecutedBy = 'The content of this resource was created by a related App or software program'
     isCreatedBy = 'The content of this resource was created by'
-    isVersionOf = 'Version Of'
-    isReplacedBy = 'Replaced By'
-    isDataFor = 'The content of this resource serves as the data for'
-    cites = 'This resource cites'
+    isVersionOf = 'This resource updates and replaces a previous version'
+    isReplacedBy = 'This resource has been replaced by a newer version'
     isDescribedBy = 'This resource is described by'
+    conformsTo = 'This resource conforms to established standard described by'
+    hasFormat = 'This resource has a related resource in another format'
+    isFormatOf = 'This resource is a different format of'
+    isRequiredBy = 'This resource is required by'
+    requires = 'This resource requires'
+    isReferencedBy = 'This resource is referenced by'
+    references = 'The content of this resource references'
+    replaces = 'This resource replaces'
+    source = 'The content of this resource is derived from'
 
 
 class AggregationType(StringEnum):
